@@ -24,12 +24,13 @@
 #include <qscrollbar.h>
 #include <qsplitter.h>
 #include <qstackedwidget.h>
+#include <qmimedata.h>
 
-#include <kglobalsettings.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kmenu.h>
+#include <KLocalizedString>
+#include <qmenu.h>
 #include <kcolorscheme.h>
+#include <kurlmimedata.h>
 
 #include "settings.h"
 
@@ -68,18 +69,22 @@ class SidebarItem : public QListWidgetItem
 
 class SidebarDelegate : public QAbstractItemDelegate
 {
+    Q_OBJECT
+
     public:
-        SidebarDelegate( QObject *parent = 0 );
-        ~SidebarDelegate();
+        SidebarDelegate( QObject *parent = Q_NULLPTR );
+        ~SidebarDelegate() override;
 
         void setShowText( bool show );
         bool isTextShown() const;
 
-        void updateBrushCache();
 
         // from QAbstractItemDelegate
-        void paint( QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index ) const;
-        QSize sizeHint( const QStyleOptionViewItem &option, const QModelIndex &index ) const;
+        void paint( QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index ) const override;
+        QSize sizeHint( const QStyleOptionViewItem &option, const QModelIndex &index ) const override;
+
+    private slots:
+        void updateBrushCache();
 
     private:
         bool m_showText;
@@ -95,6 +100,7 @@ SidebarDelegate::SidebarDelegate( QObject *parent )
     m_selectionBackground( 0 ), m_selectionForeground( 0 )
 {
     updateBrushCache();
+    connect(qApp, &QGuiApplication::paletteChanged, this, &SidebarDelegate::updateBrushCache);
 }
 
 SidebarDelegate::~SidebarDelegate()
@@ -149,7 +155,7 @@ void SidebarDelegate::paint( QPainter *painter, const QStyleOptionViewItem &opti
         foreColor = m_windowForeground->brush(option.palette).color();
     }
     QStyle *style = QApplication::style();
-    QStyleOptionViewItemV4 opt( option );
+    QStyleOptionViewItem opt( option );
     // KStyle provides an "hover highlight" effect for free;
     // but we want that for non-KStyle-based styles too
     if ( !style->inherits( "KStyle" ) && hover )
@@ -208,17 +214,25 @@ QSize SidebarDelegate::sizeHint( const QStyleOptionViewItem &option, const QMode
 class SidebarListWidget : public QListWidget
 {
     public:
-        SidebarListWidget( QWidget *parent = 0 );
-        ~SidebarListWidget();
+        SidebarListWidget( QWidget *parent = Q_NULLPTR );
+        ~SidebarListWidget() override;
+
+        int countVisible() const {
+            int ret = 0;
+            for ( int i = 0, c = count(); i < c; ++i ) {
+                ret += !item(i)->isHidden();
+            }
+            return ret;
+        }
 
     protected:
         // from QListWidget
-        void mouseDoubleClickEvent( QMouseEvent *event );
-        void mouseMoveEvent( QMouseEvent *event );
-        void mousePressEvent( QMouseEvent *event );
-        void mouseReleaseEvent( QMouseEvent *event );
+        void mouseDoubleClickEvent( QMouseEvent *event ) override;
+        void mouseMoveEvent( QMouseEvent *event ) override;
+        void mousePressEvent( QMouseEvent *event ) override;
+        void mouseReleaseEvent( QMouseEvent *event ) override;
 
-        QModelIndex moveCursor( QAbstractItemView::CursorAction cursorAction, Qt::KeyboardModifiers modifiers );
+        QModelIndex moveCursor( QAbstractItemView::CursorAction cursorAction, Qt::KeyboardModifiers modifiers ) override;
 
     private:
         // These two are used to keep track of the row an initial mousePress-
@@ -423,10 +437,7 @@ public:
 
 void Sidebar::Private::adjustListSize( bool recalc, bool expand )
 {
-    QRect bottomElemRect(
-        QPoint( 0, 0 ),
-        list->sizeHintForIndex( list->model()->index( list->count() - 1, 0 ) )
-    );
+    QSize bottomElemSize( list->sizeHintForIndex( list->model()->index( list->count() - 1, 0 ) ) );
     if ( recalc )
     {
         int w = 0;
@@ -436,15 +447,15 @@ void Sidebar::Private::adjustListSize( bool recalc, bool expand )
             if ( s.width() > w )
                 w = s.width();
         }
-        bottomElemRect.setWidth( w );
+        bottomElemSize.setWidth( w );
     }
-    bottomElemRect.translate( 0, bottomElemRect.height() * ( list->count() - 1 ) );
-    itemsHeight = bottomElemRect.height() * list->count();
+    itemsHeight = bottomElemSize.height() * list->countVisible();
     list->setMinimumHeight( itemsHeight + list->frameWidth() * 2 );
+
     int curWidth = list->minimumWidth();
     int newWidth = expand
-                   ? qMax( bottomElemRect.width() + list->frameWidth() * 2, curWidth )
-                   : qMin( bottomElemRect.width() + list->frameWidth() * 2, curWidth );
+                   ? qMax( bottomElemSize.width() + list->frameWidth() * 2, curWidth )
+                   : qMin( bottomElemSize.width() + list->frameWidth() * 2, curWidth );
     list->setFixedWidth( newWidth );
 }
 
@@ -474,7 +485,6 @@ Sidebar::Sidebar( QWidget *parent )
     d->list->setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
     d->list->setContextMenuPolicy( Qt::CustomContextMenu );
     d->list->viewport()->setAutoFillBackground( false );
-    d->list->setFont( KGlobalSettings::toolBarFont() );
 
     d->splitter = new QSplitter( this );
     mainlay->addWidget( d->splitter );
@@ -498,11 +508,8 @@ Sidebar::Sidebar( QWidget *parent )
     d->stack = new QStackedWidget( d->sideContainer );
     d->vlay->addWidget( d->stack );
 
-    connect( d->list, SIGNAL(customContextMenuRequested(QPoint)),
-             this, SLOT(listContextMenu(QPoint)) );
-    connect( d->splitter, SIGNAL(splitterMoved(int,int)), this, SLOT(splitterMoved(int,int)) );
-
-    connect( KGlobalSettings::self(), SIGNAL(appearanceChanged()), this, SLOT(appearanceChanged()) );
+    connect(d->list, &SidebarListWidget::customContextMenuRequested, this, &Sidebar::listContextMenu);
+    connect(d->splitter, &QSplitter::splitterMoved, this, &Sidebar::splitterMoved);
 
     setCollapsed( true );
     setFocusProxy( d->list );
@@ -745,17 +752,17 @@ void Sidebar::splitterMoved( int /*pos*/, int index )
 void Sidebar::saveSplitterSize() const
 {
     Okular::Settings::setSplitterSizes( d->splitter->sizes() );
-    Okular::Settings::self()->writeConfig();
+    Okular::Settings::self()->save();
 }
 
 void Sidebar::listContextMenu( const QPoint &pos )
 {
-    KMenu menu( this );
-    menu.addTitle( i18n( "Okular" ) );
+    QMenu menu( this );
+    menu.setTitle( i18n( "Okular" ) );
     QAction *showTextAct = menu.addAction( i18n( "Show Text" ) );
     showTextAct->setCheckable( true );
     showTextAct->setChecked( d->sideDelegate->isTextShown() );
-    connect( showTextAct, SIGNAL(toggled(bool)), this, SLOT(showTextToggled(bool)) );
+    connect(showTextAct, &QAction::toggled, this, &Sidebar::showTextToggled);
     menu.addSeparator();
     QActionGroup *sizeGroup = new QActionGroup( &menu );
     int curSize = d->list->iconSize().width();
@@ -772,7 +779,7 @@ void Sidebar::listContextMenu( const QPoint &pos )
     ADD_SIZE_ACTION( i18n( "Normal Icons" ), KIconLoader::SizeMedium )
     ADD_SIZE_ACTION( i18n( "Large Icons" ), KIconLoader::SizeLarge )
 #undef ADD_SIZE_ACTION
-    connect( sizeGroup, SIGNAL(triggered(QAction*)), this, SLOT(iconSizeChanged(QAction*)) );
+    connect(sizeGroup, &QActionGroup::triggered, this, &Sidebar::iconSizeChanged);
     menu.exec( mapToGlobal( pos ) );
 }
 
@@ -783,7 +790,7 @@ void Sidebar::showTextToggled( bool on )
     d->list->reset();
     d->list->update();
     Okular::Settings::setSidebarShowText( on );
-    Okular::Settings::self()->writeConfig();
+    Okular::Settings::self()->save();
 }
 
 void Sidebar::iconSizeChanged( QAction *action )
@@ -795,22 +802,17 @@ void Sidebar::iconSizeChanged( QAction *action )
     d->list->reset();
     d->list->update();
     Okular::Settings::setSidebarIconSize( size );
-    Okular::Settings::self()->writeConfig();
-}
-
-void Sidebar::appearanceChanged()
-{
-    d->sideDelegate->updateBrushCache();
+    Okular::Settings::self()->save();
 }
 
 void Sidebar::dragEnterEvent( QDragEnterEvent* event )
 {
-    event->setAccepted( KUrl::List::canDecode(event->mimeData()) );
+    event->setAccepted( event->mimeData()->hasUrls() );
 }
 
 void Sidebar::dropEvent( QDropEvent* event )
 {
-    const KUrl::List list = KUrl::List::fromMimeData( event->mimeData() );
+    const QList<QUrl> list = KUrlMimeData::urlsFromMimeData( event->mimeData() );
     emit urlsDropped( list );
 }
 
